@@ -59,12 +59,7 @@ class RequestFailed(RequestException):
 
 
 def make_server_request(
-    token,
-    endpoint,
-    data=None,
-    method: str = "GET",
-    timeout: int = None,
-    suppress_user_msg: bool = False,
+    token, endpoint, data=None, method: str = "GET", timeout: int = None, suppress_user_msg: bool = False,
 ):
     """
         Raise RequestFailed or ConnectionError.
@@ -80,7 +75,7 @@ def make_server_request(
 
     server = get_duckietown_server_url()
     url = server + endpoint
-
+    dclogger.debug(url=url)
     headers = {}
     if token is not None:
         headers["X-Messaging-Token"] = token
@@ -127,7 +122,6 @@ def make_server_request(
             msg += "\n\n" + indent(err_msg, "  > ")
             raise ConnectionError(msg) from e
 
-
         if e.code == 400:
             msg = "Invalid request to server."
             msg += f"\n\n{received_msg}"
